@@ -17,7 +17,7 @@ use Class::Accessor::Lite (
     ro  => [ qw(conf dbh) ],
 );
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub load {
     my $v = Data::Validator->new(
@@ -170,13 +170,15 @@ sub _make_fixture_yaml {
     )->with(qw/Method/);
     my($self, $args) = $v->validate(@_);
 
-    my %tmp_args = %$args;
+    my %tmp_args     = %$args;
+    my $fixture_path = File::Spec->catfile($self->conf->{fixture_path}, "$tmp_args{table}.yaml");
+
     make_fixture_yaml(
         $self->dbh,
         $tmp_args{table},
         $tmp_args{columns},
         $tmp_args{sql},
-        $self->conf->{fixture_path} . $tmp_args{table} . ".yaml"
+        $fixture_path,
     );
 }
 
@@ -198,13 +200,13 @@ DBIx::Fixture::Admin - facilitate data management by the fixtures
     my $dbh = DBI->connect("DBI:mysql:sample", "root", "");
 
     my $admin = DBIx::Fixture::Admin->new(
-        +{
+        conf => +{
             fixture_path  => "./fixture/",
             driver        => "mysql",
             load_opt      => "update",
-            dbh           => $dbh,
             ignore_tables => ["user_.*", ".*_log"]  # ignore management
         },
+        dbh => $dbh,
     );
 
     $admin->load_all(); # load all fixture
